@@ -1,9 +1,3 @@
-#!/usr/bin/env python
-# coding: utf-8
-
-# Copyright (c) Saga Inc.
-# Distributed under the terms of the GPL License.
-
 """
 For each column header, Mito creates a static `column_id` that
 is used to identify that column header throughout the entire course
@@ -18,8 +12,7 @@ of the column header. For string column headers, they are just
 themselves.
 """
 import random
-from typing import Any, Collection, Dict, List, Optional
-import numpy as np
+from typing import Any, Collection, Dict, List
 
 import pandas as pd
 
@@ -27,6 +20,25 @@ from mitosheet.errors import make_no_column_error
 from mitosheet.types import ColumnHeader, ColumnID, MultiLevelColumnHeader
 
 
+def flatten_column_header(column_header: ColumnHeader) -> ColumnHeader:
+    """
+    Given a pandas column header, if it is a list or tuple, it will
+    flatten this header into a string. 
+
+    This is useful for headers that are created from a pivot table,
+    where they are often tuples or lists.
+
+    NOTE: This function, if applied before the depricated make_valid_header
+    function, should return the same result for any input. That is:
+    For all column headers:
+    make_valid_header(flatten_column_header(ch)) = make_valid_header(ch)
+    """
+    if isinstance(column_header, list) or isinstance(column_header, tuple):
+        column_header_str = [str(ch) for ch in column_header]
+        return ' '.join(column_header_str).strip()
+
+    return column_header
+
 def get_column_header_display(column_header: ColumnHeader) -> str:
     """
     Turns the column header into a string that is the same as how
@@ -119,6 +131,7 @@ class ColumnIDMap():
         headers, in which case even if the new column header is just a string, the
         the column header that ends up getting created in the dataframe will be a 
         tuple.
+        
         """
         # Make sure the new column header we're setting is in fact valid for this dataframe
         # header format - as it may be a multi-index header
@@ -133,7 +146,7 @@ class ColumnIDMap():
         self.column_id_to_column_header[sheet_index][column_id] = column_header
         self.column_header_to_column_id[sheet_index][column_header] = column_id
 
-    def add_df(self, df: pd.DataFrame, sheet_index: Optional[int]=None, use_deprecated_id_algorithm: bool=False) -> Dict[str, ColumnHeader]:
+    def add_df(self, df: pd.DataFrame, sheet_index: int=None, use_deprecated_id_algorithm: bool=False) -> Dict[str, ColumnHeader]:
         """
         Adds all of the keys for the new dataframe to the column id 
         mappings.
@@ -165,7 +178,7 @@ class ColumnIDMap():
         self.column_id_to_column_header.pop(sheet_index)
         self.column_header_to_column_id.pop(sheet_index)
     
-    def add_column_header(self, sheet_index: int, column_header: ColumnHeader, column_id: Optional[ColumnID]=None) -> str:
+    def add_column_header(self, sheet_index: int, column_header: ColumnHeader) -> str:
         """
         NOTE: this should only be called when adding a column to the dataframe,
         and not when renaming a column, as it creates a new id for the column
@@ -178,9 +191,7 @@ class ColumnIDMap():
             column_header
         )
 
-        if column_id is None:
-            column_id = get_column_header_id(column_header)
-            
+        column_id = get_column_header_id(column_header)
         self.column_id_to_column_header[sheet_index][column_id] = column_header
         self.column_header_to_column_id[sheet_index][column_header] = column_id
 
@@ -191,9 +202,7 @@ class ColumnIDMap():
         del self.column_id_to_column_header[sheet_index][column_id]
         self.column_header_to_column_id[sheet_index][column_header]
 
-    # Note: The object returned by this function might not reflect the actual order of columns.
-    # To access the list of columns in order, use the dataframe's columns.tolist() method. 
-    def get_column_ids(self, sheet_index: int, column_headers: Optional[Collection[ColumnHeader]]=None) -> List[str]:
+    def get_column_ids(self, sheet_index: int, column_headers: Collection[ColumnHeader]=None) -> List[str]:
         if column_headers is None:
             return list(self.column_id_to_column_header[sheet_index].keys())
         try:
@@ -204,28 +213,12 @@ class ColumnIDMap():
         except:
             raise make_no_column_error(column_headers)
 
-    def get_column_headers(self, sheet_index: int) -> List[ColumnHeader]:
-        return list(self.column_id_to_column_header[sheet_index].values())
-
     def get_column_ids_map(self, sheet_index: int) -> Dict[str, ColumnHeader]:
         return self.column_id_to_column_header[sheet_index]
 
     def get_column_id_by_header(self, sheet_index: int, column_header: ColumnHeader) -> str:
-        # We handle nan values here because nan values are not hashable, and so
-        # we can't use them as keys in the column_header_to_column_id dict
-        if isinstance(column_header, float) and np.isnan(column_header):
-            for header, column_id in self.column_header_to_column_id[sheet_index].items():
-                if isinstance(header, float) and np.isnan(header):
-                    return column_id
-
         return self.column_header_to_column_id[sheet_index][column_header]
 
-    def get_column_ids_by_headers(self, sheet_index: int, column_headers: List[ColumnHeader]) -> List[ColumnID]:
-        return [
-            self.column_header_to_column_id[sheet_index][column_header] 
-            for column_header in column_headers
-        ]
-
     def get_column_header_by_id(self, sheet_index: int, column_id: ColumnID) -> ColumnHeader:
         return self.column_id_to_column_header[sheet_index][column_id]
 
