@@ -1,18 +1,12 @@
-#!/usr/bin/env python
-# coding: utf-8
-
-# Copyright (c) Saga Inc.
-# Distributed under the terms of the GPL License.
-
 from typing import Any, Dict, List, Optional, Set, Type
-import json
-from mitosheet.code_chunks.code_chunk import CodeChunk
+from mitosheet.evaluation_graph_utils import create_column_evaluation_graph
+
 from mitosheet.step_performers.step_performer import StepPerformer
 from mitosheet.step_performers.column_steps.set_column_formula import SetColumnFormulaStepPerformer
 from mitosheet.step_performers.filter import FilterStepPerformer
 from mitosheet.state import State
 from mitosheet.step_performers import STEP_TYPE_TO_STEP_PERFORMER
-from mitosheet.types import FORMULA_SPECIFIC_INDEX_LABELS_TYPE, ColumnHeader, ColumnID, FORMULA_ENTIRE_COLUMN_TYPE
+from mitosheet.types import ColumnHeader, ColumnID
 
 
 class Step:
@@ -62,8 +56,7 @@ class Step:
         # execution_data is data from the execution of the data transformation that
         # is useful for the transpiler - that means the transpiler can do way less
         # work if it has already been done. See simple_import for an example
-        self.execution_data = execution_data if execution_data is not None else {}
-
+        self.execution_data = execution_data
 
     @property
     def dfs(self):
@@ -82,24 +75,23 @@ class Step:
         return self.post_state.column_ids
     
     @property
-    def column_formulas(self):
-        return self.post_state.column_formulas
+    def column_spreadsheet_code(self):
+        return self.post_state.column_spreadsheet_code
+
+    @property
+    def column_evaluation_graph(self):
+        return [
+            create_column_evaluation_graph(self.post_state, sheet_index)
+            for sheet_index in range(len(self.dfs))
+        ]
     
     @property
     def column_filters(self):
         return self.post_state.column_filters
 
     @property
-    def df_formats(self):
-        return self.post_state.df_formats
-
-    @property
-    def graph_data_array(self) -> List[Dict[str, Any]]:
-        """
-        graph_data_array contains all of the parameters used to construct the graph,
-        the actual graph html & javascript, and the generated code for all of the existing graphs in Mito.
-        """
-        return self.final_defined_state.graph_data_array
+    def column_format_types(self):
+        return self.post_state.column_format_types
 
     @property
     def step_performer(self) -> Type[StepPerformer]:
@@ -113,25 +105,16 @@ class Step:
         step_performer = STEP_TYPE_TO_STEP_PERFORMER[self.step_type]
         return step_performer
 
-    @property
-    def initial_defined_state(self) -> State:
-        """
-        Returns the initial defined state in this step, as the prev and post
-        state are optional, but we also need a step to have a defined state
-        """
-        return self.prev_state if self.prev_state is not None else \
-            (self.post_state if self.post_state is not None else State([], public_interface_version=1))
-
     @property
     def final_defined_state(self) -> State:
         """
         Returns the final defined state in this step, as the prev and post
-        state are optional, but we also need a step to have a defined state
+        state are optional, but we also need a step to have a defined step
         """
         return self.post_state if self.post_state is not None else \
-            (self.prev_state if self.prev_state is not None else State([], 1))
+            (self.prev_state if self.prev_state is not None else State([]))
 
-    def set_prev_state_and_execute(self, new_prev_state: State, previous_steps: List["Step"]) -> bool:
+    def set_prev_state_and_execute(self, new_prev_state: State) -> None:
         """
         Changes the prev_state of this step, which in turns triggers
         a reexecution with the same parameters. 
@@ -141,36 +124,28 @@ class Step:
 
         NOTE: this is the only function you should use to get a step
         to execute!
-
-        Returns True if the step returns a new post_state, meaning an
-        execution actually occured.
         """        
         # Saturate the event to get up to date parameters
-        # TODO: this should fill in the execution data - hopefully
-        # we can get all of it without executing. I think we probably can
-        params = self.step_performer.saturate(new_prev_state, self.params, previous_steps)
+        params = self.step_performer.saturate(new_prev_state, self.params)
 
         # Actually execute the data transformation
-        post_state_and_execution_data = self.step_performer.execute(new_prev_state, params)
+        post_state_and_execution_data = self.step_performer.execute(new_prev_state, **params)
 
         if post_state_and_execution_data is not None:
             # If we don't get anything new back, then we just make this
             # step a no-op, and don't do anything
             (new_post_state, execution_data) = post_state_and_execution_data
-
         else:
             # Sometimes step execution returns None, which functionally means that 
             # nothing changed in the step (but we need not error). In this case, we
             # just don't change anything in the state
-            new_post_state, execution_data = new_prev_state, {}
+            new_post_state, execution_data = new_prev_state, []
         
         # Update the relevant state variables
         self.prev_state = new_prev_state
         self.post_state = new_post_state
-        self.execution_data = execution_data if execution_data is not None else {}
+        self.execution_data = execution_data
         self.params = params
-
-        return post_state_and_execution_data is not None
     
 
     def step_indexes_to_skip(self, all_steps_before_this_step: List['Step']) -> Set[int]:
@@ -181,8 +156,7 @@ class Step:
         Currently, a step only skips the steps before it if:
         1. This step is a filter step that is trying to replace an older filter step
         2. This step has the same id as any step before it (like for pivot tables)
-        3. This step is a formula step overwriting the step that came just before it AND they both set the entire column
-        4. This step is a formula step overwriting the step that came just before it AND they both set the same indexes
+        3. This step is a formula step overwriting the step that came just before it
         """
 
         step_indexes_to_skip = set()
@@ -201,15 +175,9 @@ class Step:
         if len(all_steps_before_this_step) > 0:
             previous_step: Step = all_steps_before_this_step[-1]
             
-            # Check (3) and (4)
-            if self.step_type == SetColumnFormulaStepPerformer.step_type() and previous_step.step_type == SetColumnFormulaStepPerformer.step_type():
-                both_entire_column = self.params['index_labels_formula_is_applied_to']['type'] == FORMULA_ENTIRE_COLUMN_TYPE and previous_step.params['index_labels_formula_is_applied_to']['type'] == FORMULA_ENTIRE_COLUMN_TYPE
-                same_indexes = (
-                    self.params['index_labels_formula_is_applied_to']['type'] == FORMULA_SPECIFIC_INDEX_LABELS_TYPE and previous_step.params['index_labels_formula_is_applied_to']['type'] == FORMULA_SPECIFIC_INDEX_LABELS_TYPE \
-                    and self.params['index_labels_formula_is_applied_to']['index_labels'] == previous_step.params['index_labels_formula_is_applied_to']['index_labels']
-                )
-                
-                if (both_entire_column or same_indexes) \
+            # Check (3)
+            if self.step_type == SetColumnFormulaStepPerformer.step_type():
+                if self.step_type == previous_step.step_type \
                     and self.params['sheet_index'] == previous_step.params['sheet_index'] \
                     and self.params['column_id'] == previous_step.params['column_id']:
                     step_indexes_to_skip.add(len(all_steps_before_this_step) - 1)
@@ -237,8 +205,4 @@ class Step:
         """
         return self.final_defined_state.column_ids.get_column_id_by_header(sheet_index, column_header)
 
-    def __repr__(self) -> str:
-        return json.dumps({
-            'step_type': self.step_type,
-            'params': self.params
-        })
+
