@@ -13,7 +13,6 @@ Examples of this sort of event are:
 - A user undoing an existing step. 
 """
 
-from mitosheet.updates.code_options_update import CODE_OPTIONS_UPDATE
 from mitosheet.updates.undo import UNDO_UPDATE
 from mitosheet.updates.redo import REDO_UPDATE
 from mitosheet.updates.clear import CLEAR_UPDATE
@@ -25,10 +24,6 @@ from mitosheet.updates.checkout_step_by_idx import CHECKOUT_STEP_BY_IDX_UPDATE
 from mitosheet.updates.append_user_field import APPEND_USER_FIELD_UPDATE
 from mitosheet.updates.update_feedback_v2_object import UPDATE_FEEDBACK_V2_OBJECT_UPDATE
 from mitosheet.updates.go_pro import GO_PRO_UPDATE
-from mitosheet.updates.render_count import RENDER_COUNT_UPDATE
-from mitosheet.updates.checklist_update import CHECKLIST_UPDATE
-from mitosheet.updates.update_existing_imports import UPDATE_EXISTING_IMPORTS_UPDATE
-from mitosheet.pro.updates.undo_to_step_index import UNDO_TO_STEP_INDEX_UPDATE
 
 
 # All update events must be listed in this variable.
@@ -44,10 +39,5 @@ UPDATES = [
     SET_USER_FIELD_UPDATE,
     CHECKOUT_STEP_BY_IDX_UPDATE,
     UPDATE_FEEDBACK_V2_OBJECT_UPDATE,
-    GO_PRO_UPDATE,
-    RENDER_COUNT_UPDATE,
-    CHECKLIST_UPDATE,
-    UPDATE_EXISTING_IMPORTS_UPDATE,
-    CODE_OPTIONS_UPDATE,
-    UNDO_TO_STEP_INDEX_UPDATE
+    GO_PRO_UPDATE
 ]
\ No newline at end of file
